#include <iostream>
#include <chrono>
#include <thread>
#include "lookup.hpp"

using namespace hebi;

int main()
{
  // Get a group
  Lookup lookup;
  std::unique_ptr<Group> group = lookup.getGroupFromNames({ "base", "shoulder", "elbow" }, { "family" });

  if (!group)
  {
    std::cout << "Group not found!";
    return -1;
  }
  
  // Set the command lifetime
  group->setCommandLifetimeMs(100);

  // Add a callback function to respond to feedback with a "virtual spring" command
  double spring_constant = -10; // Nm / rad
  GroupCommand group_command(group->size());
  group->addFeedbackHandler([&group, &group_command, &spring_constant](const GroupFeedback* group_fbk)
  {
    // Apply Hooke's law: F = -k * x
    group_command.setTorque(spring_constant * group_fbk->getPosition());
    group->sendCommand(group_command);
  });
  
  // Control the robot at 100 Hz for 30 seconds
  group->setFeedbackFrequencyHz(100);
  std::this_thread::sleep_for(std::chrono::seconds(30));
  group->clearFeedbackHandlers();

  return 0;
}
